@@ -7,6 +7,13 @@ define('DB_HOST', 'localhost');    // 99% chance you won't need to change this v
 define('DB_CHARSET', 'utf8');
 define('DB_COLLATE', '');
 
+// Change each KEY to a different unique phrase.  You won't have to remember the phrases later,
+// so make them long and complicated.  You can visit http://api.wordpress.org/secret-key/1.1/
+// to get keys generated for you, or just make something up.  Each key should have a different phrase.
+define('AUTH_KEY', 'put your unique phrase here'); // Change this to a unique phrase.
+define('SECURE_AUTH_KEY', 'put your unique phrase here'); // Change this to a unique phrase.
+define('LOGGED_IN_KEY', 'put your unique phrase here'); // Change this to a unique phrase.
+
 // You can have multiple installations in one database if you give each a unique prefix
 $table_prefix  = 'wp_';   // Only numbers, letters, and underscores please!
 
@@ -18,6 +25,7 @@ define ('WPLANG', '');
 
 /* That's all, stop editing! Happy blogging. */
 
-define('ABSPATH', dirname(__FILE__).'/');
-require_once(ABSPATH.'wp-settings.php');
+if ( !defined('ABSPATH') )
+	define('ABSPATH', dirname(__FILE__) . '/');
+require_once(ABSPATH . 'wp-settings.php');
 ?>
