@@ -465,7 +465,7 @@ function get_posts($args = null) {
 		'order' => 'DESC', 'include' => '',
 		'exclude' => '', 'meta_key' => '',
 		'meta_value' =>'', 'post_type' => 'post',
-		'post_parent' => 0
+		'post_parent' => 0, 'suppress_filters' => true
 	);
 
 	$r = wp_parse_args( $args, $defaults );
@@ -511,6 +511,10 @@ function get_posts($args = null) {
 function add_post_meta($post_id, $meta_key, $meta_value, $unique = false) {
 	global $wpdb;
 
+	// make sure meta is added to the post, not a revision
+	if ( $the_post = wp_is_post_revision($post_id) )
+		$post_id = $the_post;
+
 	// expected_slashed ($meta_key)
 	$meta_key = stripslashes($meta_key);
 
@@ -545,7 +549,9 @@ function add_post_meta($post_id, $meta_key, $meta_value, $unique = false) {
 function delete_post_meta($post_id, $key, $value = '') {
 	global $wpdb;
 
-	$post_id = absint( $post_id );
+	// make sure meta is added to the post, not a revision
+	if ( $the_post = wp_is_post_revision($post_id) )
+		$post_id = $the_post;
 
 	// expected_slashed ($key, $value)
 	$key = stripslashes( $key );
@@ -590,27 +596,20 @@ function get_post_meta($post_id, $key, $single = false) {
 
 	$meta_cache = wp_cache_get($post_id, 'post_meta');
 
-	if ( isset($meta_cache[$key]) ) {
-		if ( $single ) {
-			return maybe_unserialize( $meta_cache[$key][0] );
-		} else {
-			return maybe_unserialize( $meta_cache[$key] );
-		}
-	}
-
 	if ( !$meta_cache ) {
 		update_postmeta_cache($post_id);
 		$meta_cache = wp_cache_get($post_id, 'post_meta');
 	}
 
-	if ( $single ) {
-		if ( isset($meta_cache[$key][0]) )
-			return maybe_unserialize($meta_cache[$key][0]);
-		else
-			return '';
-	} else {
-		return maybe_unserialize($meta_cache[$key]);
+	if ( isset($meta_cache[$key]) ) {
+		if ( $single ) {
+			return maybe_unserialize( $meta_cache[$key][0] );
+		} else {
+			return array_map('maybe_unserialize', $meta_cache[$key]);
+		}
 	}
+
+	return '';
 }
 
 /**
@@ -633,6 +632,10 @@ function get_post_meta($post_id, $key, $single = false) {
 function update_post_meta($post_id, $meta_key, $meta_value, $prev_value = '') {
 	global $wpdb;
 
+	// make sure meta is added to the post, not a revision
+	if ( $the_post = wp_is_post_revision($post_id) )
+		$post_id = $the_post;
+
 	// expected_slashed ($meta_key)
 	$meta_key = stripslashes($meta_key);
 
@@ -1272,14 +1275,14 @@ function wp_insert_post($postarr = array(), $wp_error = false) {
 	}
 
 	// If the post date is empty (due to having been new or a draft) and status is not 'draft', set date to now
-	if (empty($post_date)) {
+	if ( empty($post_date) || '0000-00-00 00:00:00' == $post_date ) {
 		if ( !in_array($post_status, array('draft', 'pending')) )
 			$post_date = current_time('mysql');
 		else
 			$post_date = '0000-00-00 00:00:00';
 	}
 
-	if (empty($post_date_gmt)) {
+	if ( empty($post_date_gmt) || '0000-00-00 00:00:00' == $post_date_gmt ) {
 		if ( !in_array($post_status, array('draft', 'pending')) )
 			$post_date_gmt = get_gmt_from_date($post_date);
 		else
@@ -3113,7 +3116,6 @@ function _wp_post_revision_fields( $post = null, $autosave = false ) {
 		// Allow these to be versioned
 		$fields = array(
 			'post_title' => __( 'Title' ),
-			'post_author' => __( 'Author' ),
 			'post_content' => __( 'Content' ),
 			'post_excerpt' => __( 'Excerpt' ),
 		);
@@ -3122,7 +3124,7 @@ function _wp_post_revision_fields( $post = null, $autosave = false ) {
 		$fields = apply_filters( '_wp_post_revision_fields', $fields );
 
 		// WP uses these internally either in versioning or elsewhere - they cannot be versioned
-		foreach ( array( 'ID', 'post_name', 'post_parent', 'post_date', 'post_date_gmt', 'post_status', 'post_type', 'comment_count' ) as $protect )
+		foreach ( array( 'ID', 'post_name', 'post_parent', 'post_date', 'post_date_gmt', 'post_status', 'post_type', 'comment_count', 'post_author' ) as $protect )
 			unset( $fields[$protect] );
 	}
 
@@ -3294,7 +3296,7 @@ function _wp_put_post_revision( $post = null, $autosave = false ) {
 	if ( !$post || empty($post['ID']) )
 		return;
 
-	if ( isset($post['post_type']) && 'revision' == $post_post['type'] )
+	if ( isset($post['post_type']) && 'revision' == $post['post_type'] )
 		return new WP_Error( 'post_type', __( 'Cannot create a revision of a revision' ) );
 
 	$post = _wp_post_revision_fields( $post, $autosave );
